package com.ruoyi.frequency.orderoperatorhistory.service;

import java.util.List;
import com.ruoyi.frequency.orderoperatorhistory.entity.OrderOperatorHistory;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 订单操作记录Service接口
 * 
 * @author liwenlong
 * @date 2024-06-12
 */
public interface OrderOperatorHistoryService extends IService<OrderOperatorHistory>
{
    /**
     * 查询订单操作记录
     * 
     * @param id 订单操作记录主键
     * @return 订单操作记录
     */
    public OrderOperatorHistory selectOrderOperatorHistoryById(Long id);

    /**
     * 查询订单操作记录列表
     * 
     * @param orderOperatorHistory 订单操作记录
     * @return 订单操作记录集合
     */
    public List<OrderOperatorHistory> selectOrderOperatorHistoryList(OrderOperatorHistory orderOperatorHistory);

    /**
     * 新增订单操作记录
     * 
     * @param orderOperatorHistory 订单操作记录
     * @return 结果
     */
    public int insertOrderOperatorHistory(OrderOperatorHistory orderOperatorHistory);

    /**
     * 修改订单操作记录
     * 
     * @param orderOperatorHistory 订单操作记录
     * @return 结果
     */
    public int updateOrderOperatorHistory(OrderOperatorHistory orderOperatorHistory);

    /**
     * 批量删除订单操作记录
     * 
     * @param ids 需要删除的订单操作记录主键集合
     * @return 结果
     */
    public int deleteOrderOperatorHistoryByIds(Long[] ids,Integer delFlag);

}
